# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    NewType as typing___NewType,
    cast as typing___cast,
)


builtin___int = int


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

OptionalBooleanValue = typing___NewType('OptionalBooleanValue', builtin___int)
type___OptionalBooleanValue = OptionalBooleanValue
OptionalBoolean: _OptionalBoolean
class _OptionalBoolean(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[OptionalBooleanValue]):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    BOOL_UNSPECIFIED = typing___cast(OptionalBooleanValue, 0)
    BOOL_FALSE = typing___cast(OptionalBooleanValue, 2)
    BOOL_TRUE = typing___cast(OptionalBooleanValue, 3)
BOOL_UNSPECIFIED = typing___cast(OptionalBooleanValue, 0)
BOOL_FALSE = typing___cast(OptionalBooleanValue, 2)
BOOL_TRUE = typing___cast(OptionalBooleanValue, 3)
type___OptionalBoolean = OptionalBoolean
