# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Optional as typing___Optional,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class RegularLimitParameters(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    time: builtin___int = ...
    branches: builtin___int = ...
    failures: builtin___int = ...
    solutions: builtin___int = ...
    smart_time_check: builtin___bool = ...
    cumulative: builtin___bool = ...

    def __init__(self,
        *,
        time : typing___Optional[builtin___int] = None,
        branches : typing___Optional[builtin___int] = None,
        failures : typing___Optional[builtin___int] = None,
        solutions : typing___Optional[builtin___int] = None,
        smart_time_check : typing___Optional[builtin___bool] = None,
        cumulative : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> RegularLimitParameters: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> RegularLimitParameters: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"branches",b"branches",u"cumulative",b"cumulative",u"failures",b"failures",u"smart_time_check",b"smart_time_check",u"solutions",b"solutions",u"time",b"time"]) -> None: ...
type___RegularLimitParameters = RegularLimitParameters
